@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,8 @@
 package com.openexchange.oauth.httpclient.impl.scribe;
 
 import java.util.Map;
-
 import org.scribe.model.OAuthRequest;
 import org.scribe.model.Verb;
-
 import com.openexchange.http.client.builder.HTTPPostRequestBuilder;
 import com.openexchange.oauth.httpclient.OAuthHTTPRequestBuilder;
 
@@ -76,4 +74,14 @@ public class ScribeHTTPPostRequestBuilder extends ScribeGenericHTTPRequestBuilde
 		}
 	}
 
+	@Override
+    public void setRequestEntity(String requestEntity, String contentType) {
+        // Not supported
+    }
+
+    @Override
+    public void urlParameter(String parameter, String value) {
+        // Not supported
+    }
+
 }
