@@ -71,7 +71,6 @@ import org.osgi.service.event.EventAdmin;
 import org.scribe.builder.ServiceBuilder;
 import org.scribe.builder.api.Api;
 import org.scribe.builder.api.DropBoxApi;
-import org.scribe.builder.api.FacebookApi;
 import org.scribe.builder.api.FlickrApi;
 import org.scribe.builder.api.FoursquareApi;
 import org.scribe.builder.api.Google2Api;
@@ -85,7 +84,6 @@ import org.scribe.model.Token;
 import org.scribe.model.Verifier;
 import com.openexchange.context.ContextService;
 import com.openexchange.crypto.CryptoService;
-import com.openexchange.database.Databases;
 import com.openexchange.database.provider.DBProvider;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
@@ -414,7 +412,7 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
              * Set display name & identifier
              */
             final String displayName = (String) arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME);
-            if (isEmpty(displayName)) {
+            if (Strings.isEmpty(displayName)) {
                 throw OAuthExceptionCodes.MISSING_ARGUMENT.create(OAuthConstants.ARGUMENT_DISPLAY_NAME);
             }
             account.setDisplayName(displayName);
@@ -468,7 +466,7 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
              * Set display name & identifier
              */
             final String displayName = (String) arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME);
-            if (isEmpty(displayName)) {
+            if (Strings.isEmpty(displayName)) {
                 throw OAuthExceptionCodes.MISSING_ARGUMENT.create(OAuthConstants.ARGUMENT_DISPLAY_NAME);
             }
             account.setDisplayName(displayName);
@@ -484,7 +482,7 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
             if (null == session) {
                 throw OAuthExceptionCodes.MISSING_ARGUMENT.create(OAuthConstants.ARGUMENT_SESSION);
             }
-            if (isEmpty(account.getToken())) {
+            if (Strings.isEmpty(account.getToken())) {
                 throw OAuthExceptionCodes.MISSING_ARGUMENT.create(OAuthConstants.ARGUMENT_TOKEN);
             }
             account.setToken(encrypt(account.getToken(), session));
@@ -845,8 +843,6 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
                 apiClass = YahooApi.class;
             } else if (serviceId.indexOf("foursquare") >= 0) {
                 apiClass = FoursquareApi.class;
-            } else if (serviceId.indexOf("facebook") >= 0) {
-                apiClass = FacebookApi.class;
             } else if (serviceId.indexOf("tumblr") >= 0) {
                 apiClass = TumblrApi.class;
             } else if (serviceId.indexOf("flickr") >= 0) {
@@ -949,33 +945,24 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
     }
 
     private String encrypt(final String toEncrypt, final Session session) throws OXException {
-        if (isEmpty(toEncrypt)) {
+        if (Strings.isEmpty(toEncrypt)) {
             return toEncrypt;
         }
         final SecretEncryptionService<PWUpdate> service = Services.getService(SecretEncryptionFactoryService.class).createService(this);
         return service.encrypt(session, toEncrypt);
     }
 
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
     @Override
     public void update(final String recrypted, final PWUpdate customizationNote) throws OXException {
+        final StringBuilder b = new StringBuilder();
+        b.append("UPDATE oauthAccounts SET ").append(customizationNote.field).append("= ? WHERE cid = ? AND id = ?");
+
         final Context context = getContext(customizationNote.cid);
         Connection con = null;
         PreparedStatement stmt = null;
         try {
             con = getConnection(false, context);
-            stmt = con.prepareStatement(new StringBuilder("UPDATE oauthAccounts SET ").append(customizationNote.field).append("= ? WHERE cid = ? AND id = ?").toString());
+            stmt = con.prepareStatement(b.toString());
             stmt.setString(1, recrypted);
             stmt.setInt(2, customizationNote.cid);
             stmt.setInt(3, customizationNote.id);
@@ -983,7 +970,6 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
         } catch (final SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e.getMessage());
         } finally {
-            Databases.closeSQLStuff(stmt);
             provider.releaseWriteConnection(context, con);
         }
     }
@@ -1010,11 +996,11 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
                 try {
                     // Try using the secret.
                     final String accessToken = rs.getString(2);
-                    if (!isEmpty(accessToken)) {
+                    if (!Strings.isEmpty(accessToken)) {
                         cryptoService.decrypt(accessToken, secret);
                     }
                     final String accessSecret = rs.getString(3);
-                    if (!isEmpty(accessSecret)) {
+                    if (!Strings.isEmpty(accessSecret)) {
                         cryptoService.decrypt(accessSecret, secret);
                     }
                 } catch (final OXException e) {
@@ -1079,11 +1065,11 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
                 try {
                     // Try using the secret.
                     final String accessToken = rs.getString(2);
-                    if (!isEmpty(accessToken)) {
+                    if (!Strings.isEmpty(accessToken)) {
                         cryptoService.decrypt(accessToken, secret);
                     }
                     final String accessSecret = rs.getString(3);
-                    if (!isEmpty(accessSecret)) {
+                    if (!Strings.isEmpty(accessSecret)) {
                         cryptoService.decrypt(accessSecret, secret);
                     }
                 } catch (final OXException e) {
@@ -1164,11 +1150,11 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
                 try {
                     // Try using the new secret. Maybe this account doesn't need the migration
                     final String accessToken = rs.getString(2);
-                    if (!isEmpty(accessToken)) {
+                    if (!Strings.isEmpty(accessToken)) {
                         cryptoService.decrypt(accessToken, newSecret);
                     }
                     final String accessSecret = rs.getString(3);
-                    if (!isEmpty(accessSecret)) {
+                    if (!Strings.isEmpty(accessSecret)) {
                         cryptoService.decrypt(accessSecret, newSecret);
                     }
                 } catch (final OXException e) {
@@ -1216,7 +1202,7 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
     private static OXException handleScribeOAuthException(org.scribe.exceptions.OAuthException e) {
         final String message = e.getMessage();
         if (null != message) {
-            final String lcMsg = toLowerCase(message);
+            final String lcMsg = com.openexchange.java.Strings.toLowerCase(message);
             String str = "can't extract token and secret from this:";
             int pos = lcMsg.indexOf(str);
             if (pos > 0) {
@@ -1251,19 +1237,4 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
         }
         return msg;
     }
-
-    /** ASCII-wise to lower-case */
-    private static String toLowerCase(final CharSequence chars) {
-        if (null == chars) {
-            return null;
-        }
-        final int length = chars.length();
-        final StringBuilder builder = new StringBuilder(length);
-        for (int i = 0; i < length; i++) {
-            final char c = chars.charAt(i);
-            builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
-        }
-        return builder.toString();
-    }
-
 }
