@@ -97,7 +97,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
 
         // Event handler
         final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
-        serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
+        serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.TOPIC_LAST_SESSION);
         registerService(EventHandler.class, new XingEventHandler(), serviceProperties);
 
         // Registerer
